@@ -58,17 +58,31 @@ class CameraCtrlsWindow(Gtk.ApplicationWindow):
             padding-left: 10px;
             padding-right: 10px;
         }
-        /* scale layout fix */
-        scale trough {
-            margin-top: 7px;
-            margin-bottom: -7px;
-        }
         '''
-        if (Gtk.get_major_version(), Gtk.get_minor_version()) >= (4, 12):
+
+        gtk_version = (Gtk.get_major_version(), Gtk.get_minor_version(), Gtk.get_micro_version())
+
+        if gtk_version >= (4, 14, 2):
+            css += '''
+            /* scale layout fix */
+            scale {
+                padding: 8px;
+            }
+            '''
+        else:
+            css += '''
+            /* scale layout fix */
+            scale trough {
+                margin-top: 7px;
+                margin-bottom: -7px;
+            }
+            '''
+
+        if gtk_version >= (4, 12, 0):
             css_provider.load_from_string(css)
         # XXX: remove workaround when merged and pygobject 3.46 is widespread
         # https://gitlab.gnome.org/GNOME/pygobject/-/merge_requests/231/
-        elif (Gtk.get_major_version(), Gtk.get_minor_version()) >= (4, 9):
+        elif gtk_version >= (4, 9, 0):
             css_provider.load_from_data(css, -1)
         else:
             css_provider.load_from_data(css.encode())
@@ -516,9 +530,9 @@ class CameraCtrlsWindow(Gtk.ApplicationWindow):
 
     def update_ctrl_state(self, c):
         for gui_ctrl in c.gui_ctrls:
-            gui_ctrl.set_sensitive(not c.inactive)
+            gui_ctrl.set_sensitive(not c.inactive and not c.readonly)
         if c.gui_default_btn is not None:
-            visible = not c.inactive and (
+            visible = not c.inactive and not c.readonly and (
                 c.default is not None and c.value is not None and c.default != c.value or \
                 c.get_default is not None and not c.get_default()
             )
